Module driver

Module driver 

View drivers

The Driver trait is used as a binding between data models and controllers. Implementations define the view (using widgets) and message handling (mapping widget messages to actions).

A basic implementation is provided: View provides a simple read-only view over content (text labels in all cases except bool, which uses a read-only CheckBox).

Intended usage is to import the module name rather than its contents, thus allowing referal to e.g. driver::View.

Structs

View
Default view widget constructor

Traits

Driver
View widget driver